==> 0.1.9.tar.gz: lib/widget/vgk-card-horizontal-widget/vgk-card-horizontal-content-widget.dart <==
import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/material.dart';
import 'package:vgkprogaming/model/vgk-card-horizontal-model.dart';
import 'package:vgkprogaming/theme/vgk-shared-theme.dart';
import 'package:vgkprogaming/widget/vgk-sub-title-widget/vgk-sub-title-widget-with-animation.dart';

class VgkCardHorizontalContentWidget extends StatelessWidget {
  const VgkCardHorizontalContentWidget({
    Key key,
    this.data,
    this.animationController,
    this.animation,
  }) : super(key: key);

  final VgkCardHorizontalDetailModel data;
  final AnimationController animationController;
  final Animation<dynamic> animation;

  @override
  Widget build(BuildContext context) {
    return AnimatedBuilder(
      animation: animationController,
      builder: (BuildContext context, Widget child) {
        return FadeTransition(
          opacity: animation,
          child: Transform(
            transform: VgkprogamingTheme.subTransform(animation),
            child: InkWell(
              splashColor: Colors.transparent,
              child: SizedBox(
                width: 280,
                child: Stack(
                  children: <Widget>[
                    Container(
                      child: Row(
                        children: <Widget>[
                          const SizedBox(
                            width: 48,
                          ),
                          Expanded(
                            child: Container(
                              decoration: BoxDecoration(
                                color: VgkprogamingTheme
                                    .lightGreyWithOpacityMedium,
                                borderRadius:
                                    VgkprogamingTheme.borderRadiusMedium,
                              ),
                              child: Row(
                                children: <Widget>[
                                  const SizedBox(
                                    width: 48 + 24.0,
                                  ),
                                  Expanded(
                                    child: Container(
                                      child: Column(
                                        children: getCardHorizontalContent(
                                          data.data,
                                        ),
                                      ),
                                    ),
                                  ),
                                ],
                              ),
                            ),
                          )
                        ],
                      ),
                    ),
                    Container(
                      child: Padding(
                        padding: EdgeInsets.only(top: 24, bottom: 24, left: 16),
                        child: Row(
                          children: <Widget>[
                            ClipRRect(
                              borderRadius:
                                  BorderRadius.all(Radius.circular(16.0)),
                              child: Container(
                                padding: const EdgeInsets.only(
                                    top: 16, bottom: 16, right: 16, left: 16),
                                color: VgkprogamingTheme.grey.withOpacity(0.2),
                                child: AspectRatio(
                                  aspectRatio: 1.0,
                                  child: CachedNetworkImage(
                                    imageUrl: data.src,
                                    progressIndicatorBuilder: (context, url,
                                            downloadProgress) =>
                                        CircularProgressIndicator(
                                            value: downloadProgress.progress),
                                    errorWidget: (context, url, error) =>
                                        Icon(Icons.error),
                                  ),
                                  // Image.network(data.src),
                                ),
                              ),
                            ),
                          ],
                        ),
                      ),
                    ),
                  ],
                ),
              ),
            ),
          ),
        );
      },
    );
  }

  List<Widget> getCardHorizontalContent(
      List<VgkCardHorizontalSubDetailModel> details) {
    List<Widget> result = <Widget>[];
    result.add(Padding(
      padding: const EdgeInsets.only(top: 16),
      child: VgkSubTitleWithAnimationWidget(
        titleTxt: data.key,
        animation: VgkprogamingTheme.animationOption(animationController),
        animationController: animationController,
      ),
    ));
    result.add(SizedBox(
      height: 20,
    ));
    details.forEach((element) {
      if (element.key != null && element.value != null) {
        result.add(Padding(
          padding: const EdgeInsets.only(right: 16, bottom: 8),
          child: Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            crossAxisAlignment: CrossAxisAlignment.center,
            children: <Widget>[
              Expanded(
                child: Text(
                  element.key + " : " + element.value,
                  textAlign: TextAlign.left,
                  style: VgkprogamingTheme.h3Black,
                ),
              )
            ],
          ),
        ));
      }
    });
    return result;
  }
}

==> 0.2.0.tar.gz: lib/widget/vgk-card-horizontal-widget/vgk-card-horizontal-content-widget.dart <==
import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/material.dart';
import 'package:vgkprogaming/model/vgk-card-horizontal-model.dart';
import 'package:vgkprogaming/theme/vgk-shared-theme.dart';
import 'package:vgkprogaming/widget/vgk-sub-title-widget/vgk-sub-title-widget-with-animation.dart';

class VgkCardHorizontalContentWidget extends StatelessWidget {
  const VgkCardHorizontalContentWidget({
    Key key,
    this.data,
    this.animationController,
    this.animation,
  }) : super(key: key);

  final VgkCardHorizontalDetailModel data;
  final AnimationController animationController;
  final Animation<dynamic> animation;

  @override
  Widget build(BuildContext context) {
    return AnimatedBuilder(
      animation: animationController,
      builder: (BuildContext context, Widget child) {
        return FadeTransition(
          opacity: animation,
          child: Transform(
            transform: VgkprogamingTheme.subTransform(animation),
            child: InkWell(
              splashColor: Colors.transparent,
              child: SizedBox(
                width: 280,
                child: Stack(
                  children: <Widget>[
                    Container(
                      child: Row(
                        children: <Widget>[
                          const SizedBox(
                            width: 48,
                          ),
                          Expanded(
                            child: Container(
                              decoration: BoxDecoration(
                                color: VgkprogamingTheme
                                    .lightGreyWithOpacityMedium,
                                borderRadius:
                                    VgkprogamingTheme.borderRadiusMedium,
                              ),
                              child: Row(
                                children: <Widget>[
                                  const SizedBox(
                                    width: 48 + 24.0,
                                  ),
                                  Expanded(
                                    child: Container(
                                      child: Column(
                                        children: getCardHorizontalContent(
                                          data.data,
                                        ),
                                      ),
                                    ),
                                  ),
                                ],
                              ),
                            ),
                          )
                        ],
                      ),
                    ),
                    Container(
                      child: Padding(
                        padding: EdgeInsets.only(top: 24, bottom: 24, left: 16),
                        child: Row(
                          children: <Widget>[
                            ClipRRect(
                              borderRadius:
                                  BorderRadius.all(Radius.circular(16.0)),
                              child: Container(
                                padding: const EdgeInsets.only(
                                    top: 16, bottom: 16, right: 16, left: 16),
                                color: VgkprogamingTheme.grey.withOpacity(0.2),
                                child: AspectRatio(
                                  aspectRatio: 1.0,
                                  child: CachedNetworkImage(
                                    imageUrl: data.src,
                                    progressIndicatorBuilder: (context, url,
                                            downloadProgress) =>
                                        CircularProgressIndicator(
                                            value: downloadProgress.progress),
                                    errorWidget: (context, url, error) =>
                                        Icon(Icons.error),
                                  ),
                                  // Image.network(data.src),
                                ),
                              ),
                            ),
                          ],
                        ),
                      ),
                    ),
                  ],
                ),
              ),
            ),
          ),
        );
      },
    );
  }

  List<Widget> getCardHorizontalContent(
      List<VgkCardHorizontalSubDetailModel> details) {
    List<Widget> result = <Widget>[];
    result.add(Padding(
      padding: const EdgeInsets.only(top: 16),
      child: VgkSubTitleWithAnimationWidget(
        titleTxt: data.key,
        animation: VgkprogamingTheme.animationOption(animationController),
        animationController: animationController,
      ),
    ));
    result.add(SizedBox(
      height: 20,
    ));
    details.forEach((element) {
      if (element.key != null && element.value != null) {
        result.add(Padding(
          padding: const EdgeInsets.only(right: 16, bottom: 8),
          child: Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            crossAxisAlignment: CrossAxisAlignment.center,
            children: <Widget>[
              Expanded(
                child: Text(
                  element.key + " : " + element.value,
                  textAlign: TextAlign.center,
                  style: VgkprogamingTheme.h3BlackWithOpacity,
                ),
              )
            ],
          ),
        ));
      }
    });
    return result;
  }
}
